pub struct ASGD { /* private fields */ }Expand description
Averaged Stochastic Gradient Descent (ASGD) optimizer
This implements the Averaged SGD algorithm which maintains a running average of parameters during training. It can achieve better convergence properties than standard SGD in certain scenarios.
Implementations
Sourceimpl ASGD
impl ASGD
Sourcepub fn new(
params: Vec<Arc<RwLock<Tensor>>>,
lr: Option<f32>,
alpha: Option<f32>,
t0: Option<f32>,
lambd: Option<f32>,
weight_decay: Option<f32>,
) -> Self
pub fn new( params: Vec<Arc<RwLock<Tensor>>>, lr: Option<f32>, alpha: Option<f32>, t0: Option<f32>, lambd: Option<f32>, weight_decay: Option<f32>, ) -> Self
Create a new ASGD optimizer
Arguments
params- Parameters to optimizelr- Learning rate (default: 1e-2)alpha- Power for computing average (default: 0.75)t0- Point at which to start averaging (default: 1e6)lambd- Decay term (default: 1e-4)weight_decay- Weight decay (L2 penalty) (default: 0.0)