pub struct SparseAdam { /* private fields */ }Expand description
Sparse Adam optimizer
A variant of Adam that handles sparse gradients more efficiently by only updating the parameters that have non-zero gradients.
Implementations
Sourceimpl SparseAdam
impl SparseAdam
Sourcepub fn new(
params: Vec<Arc<RwLock<Tensor>>>,
lr: Option<f32>,
beta1: Option<f32>,
beta2: Option<f32>,
eps: Option<f32>,
weight_decay: Option<f32>,
) -> Self
pub fn new( params: Vec<Arc<RwLock<Tensor>>>, lr: Option<f32>, beta1: Option<f32>, beta2: Option<f32>, eps: Option<f32>, weight_decay: Option<f32>, ) -> Self
Create a new SparseAdam optimizer
Arguments
params- Parameters to optimizelr- Learning rate (default: 1e-3)beta1- First moment decay rate (default: 0.9)beta2- Second moment decay rate (default: 0.999)eps- Small constant for numerical stability (default: 1e-8)weight_decay- Weight decay (L2 penalty) (default: 0.0)