pub struct OptimizerState {
pub optimizer_type: String,
pub version: String,
pub param_groups: Vec<ParamGroupState>,
pub state: HashMap<String, HashMap<String, Tensor>>,
pub global_state: HashMap<String, f32>,
}Expand description
Optimizer state for serialization
Fields
optimizer_type: StringOptimizer type identifier
version: StringVersion of the state format
param_groups: Vec<ParamGroupState>Parameter group states
state: HashMap<String, HashMap<String, Tensor>>Per-parameter optimizer state (keyed by parameter ID)
global_state: HashMap<String, f32>Global optimizer state
Implementations
Sourceimpl OptimizerState
impl OptimizerState
Sourcepub fn total_param_count(&self) -> usize
pub fn total_param_count(&self) -> usize
Get the total number of parameters across all groups
Sourcepub fn is_compatible_with(&self, other: &OptimizerState) -> bool
pub fn is_compatible_with(&self, other: &OptimizerState) -> bool
Check if state is compatible with another state (same structure)